/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.common;

import java.util.Set;

/**
 * <p>
 * An interface for use when a provider of some object is required but 
 * the types of implementation come from elsewhere, e.g. OSGi and those 
 * types can't be on the using systems classpath.
 * </p>
 *
 * <strong>Concurrent Semantics</strong><br />
 *
 * Implementations <strong>must</strong> be thread safe.
 *
 * @author Christopher Frost
 * @param <T> type of elements of set
 * @since 1.5
 */
public interface SetProvider<T> {

    /**
     * Implementations of this must provide thread safe sets for iteration. 
     * e.g. This can be achieved by either returning a new set or one that 
     * implements thread safety with internal locking.
     * 
     * 
     * @return the <code>Set</code> of service objects
     */
    public abstract Set<T> getSet();

}
