/*
 * Copyright SpringSource Inc 2007,2009.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.util.common;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

/**
 * An implementation of {@link SetProvider} that takes a static list of elements and returns them for every request for
 * a set.
 * <p />
 * 
 * <strong>Concurrent Semantics</strong><br />
 * 
 * Threadsafe
 * 
 * @author Ben Hale
 * @param <T> type of elements of set
 */
public class StaticSetProvider<T> implements SetProvider<T> {

    private final Set<T> set;

    public StaticSetProvider(T... items) {
        Set<T> set = new HashSet<T>(items.length);
        Collections.addAll(set, items);
        this.set = Collections.unmodifiableSet(set);
    }

    public Set<T> getSet() {
        return set;
    }

}
